;+
;
; @file_comments
; compute the latitudes of the n256 gaussian grid. See:
; <a href="http://www.ecmwf.int/products/data/technical/gaussian/n256FIS.html">Gaussian 256</a>
;
; @categories
; Grid
;
; @examples
; IDL> lat=n256gaussian()
;
; @returns
; a 1d array
;
; @history
;      Sebastien Masson (smasson\@lodyc.jussieu.fr)
;      June 2004
;
; @version
; $Id$
;
;-
;
FUNCTION n256gaussian
;
  compile_opt idl2, strictarrsubs
;
;         latitude   reduced     regular  latitude
;          number     points      points
;         -------    -------     -------  --------
  n256 = [    1,         18,       1024,  89.73115, $
              2,         25,       1024,  89.38287, $
              3,         32,       1024,  89.03254, $
              4,         40,       1024,  88.68175, $
              5,         45,       1024,  88.33077, $
              6,         50,       1024,  87.97972, $
              7,         60,       1024,  87.62861, $
              8,         64,       1024,  87.27748, $
              9,         72,       1024,  86.92632, $
              10,         72,       1024,  86.57515, $
              11,         75,       1024,  86.22398, $
              12,         81,       1024,  85.87279, $
              13,         90,       1024,  85.52160, $
              14,         96,       1024,  85.17041, $
              15,        100,       1024,  84.81921, $
              16,        108,       1024,  84.46801, $
              17,        120,       1024,  84.11681, $
              18,        120,       1024,  83.76560, $
              19,        125,       1024,  83.41440, $
              20,        135,       1024,  83.06319, $
              21,        144,       1024,  82.71198, $
              22,        150,       1024,  82.36077, $
              23,        160,       1024,  82.00956, $
              24,        160,       1024,  81.65835, $
              25,        180,       1024,  81.30714, $
              26,        180,       1024,  80.95593, $
              27,        180,       1024,  80.60471, $
              28,        192,       1024,  80.25350, $
              29,        192,       1024,  79.90229, $
              30,        200,       1024,  79.55107, $
              31,        216,       1024,  79.19986, $
              32,        216,       1024,  78.84864, $
              33,        216,       1024,  78.49743, $
              34,        225,       1024,  78.14621, $
              35,        240,       1024,  77.79500, $
              36,        240,       1024,  77.44378, $
              37,        243,       1024,  77.09256, $
              38,        250,       1024,  76.74135, $
              39,        256,       1024,  76.39013, $
              40,        270,       1024,  76.03891, $
              41,        270,       1024,  75.68770, $
              42,        288,       1024,  75.33648, $
              43,        288,       1024,  74.98526, $
              44,        288,       1024,  74.63405, $
              45,        300,       1024,  74.28283, $
              46,        300,       1024,  73.93161, $
              47,        320,       1024,  73.58040, $
              48,        320,       1024,  73.22918, $
              49,        320,       1024,  72.87796, $
              50,        324,       1024,  72.52674, $
              51,        360,       1024,  72.17552, $
              52,        360,       1024,  71.82431, $
              53,        360,       1024,  71.47309, $
              54,        360,       1024,  71.12187, $
              55,        360,       1024,  70.77065, $
              56,        360,       1024,  70.41944, $
              57,        375,       1024,  70.06822, $
              58,        375,       1024,  69.71700, $
              59,        384,       1024,  69.36578, $
              60,        384,       1024,  69.01456, $
              61,        400,       1024,  68.66334, $
              62,        400,       1024,  68.31213, $
              63,        400,       1024,  67.96091, $
              64,        432,       1024,  67.60969, $
              65,        432,       1024,  67.25847, $
              66,        432,       1024,  66.90725, $
              67,        432,       1024,  66.55603, $
              68,        432,       1024,  66.20482, $
              69,        450,       1024,  65.85360, $
              70,        450,       1024,  65.50238, $
              71,        450,       1024,  65.15116, $
              72,        480,       1024,  64.79994, $
              73,        480,       1024,  64.44872, $
              74,        480,       1024,  64.09750, $
              75,        480,       1024,  63.74629, $
              76,        480,       1024,  63.39507, $
              77,        486,       1024,  63.04385, $
              78,        500,       1024,  62.69263, $
              79,        500,       1024,  62.34141, $
              80,        500,       1024,  61.99019]
  n256 = [n256, $
          81,        512,       1024,  61.63897, $
          82,        512,       1024,  61.28776, $
          83,        540,       1024,  60.93654, $
          84,        540,       1024,  60.58532, $
          85,        540,       1024,  60.23410, $
          86,        540,       1024,  59.88288, $
          87,        540,       1024,  59.53166, $
          88,        576,       1024,  59.18044, $
          89,        576,       1024,  58.82922, $
          90,        576,       1024,  58.47800, $
          91,        576,       1024,  58.12679, $
          92,        576,       1024,  57.77557, $
          93,        576,       1024,  57.42435, $
          94,        600,       1024,  57.07313, $
          95,        600,       1024,  56.72191, $
          96,        600,       1024,  56.37069, $
          97,        600,       1024,  56.01947, $
          98,        600,       1024,  55.66825, $
          99,        640,       1024,  55.31703, $
          100,        640,       1024,  54.96581, $
          101,        640,       1024,  54.61460, $
          102,        640,       1024,  54.26338, $
          103,        640,       1024,  53.91216, $
          104,        640,       1024,  53.56094, $
          105,        640,       1024,  53.20972, $
          106,        640,       1024,  52.85850, $
          107,        648,       1024,  52.50728, $
          108,        675,       1024,  52.15606, $
          109,        675,       1024,  51.80484, $
          110,        675,       1024,  51.45362, $
          111,        675,       1024,  51.10241, $
          112,        675,       1024,  50.75119, $
          113,        675,       1024,  50.39997, $
          114,        720,       1024,  50.04875, $
          115,        720,       1024,  49.69753, $
          116,        720,       1024,  49.34631, $
          117,        720,       1024,  48.99509, $
          118,        720,       1024,  48.64387, $
          119,        720,       1024,  48.29265, $
          120,        720,       1024,  47.94143, $
          121,        720,       1024,  47.59021, $
          122,        720,       1024,  47.23899, $
          123,        729,       1024,  46.88778, $
          124,        729,       1024,  46.53656, $
          125,        750,       1024,  46.18534, $
          126,        750,       1024,  45.83412, $
          127,        750,       1024,  45.48290, $
          128,        750,       1024,  45.13168, $
          129,        750,       1024,  44.78046, $
          130,        768,       1024,  44.42924, $
          131,        768,       1024,  44.07802, $
          132,        768,       1024,  43.72680, $
          133,        768,       1024,  43.37558, $
          134,        800,       1024,  43.02436, $
          135,        800,       1024,  42.67315, $
          136,        800,       1024,  42.32193, $
          137,        800,       1024,  41.97071, $
          138,        800,       1024,  41.61949, $
          139,        800,       1024,  41.26827, $
          140,        800,       1024,  40.91705, $
          141,        800,       1024,  40.56583, $
          142,        810,       1024,  40.21461, $
          143,        810,       1024,  39.86339, $
          144,        864,       1024,  39.51217, $
          145,        864,       1024,  39.16095, $
          146,        864,       1024,  38.80973, $
          147,        864,       1024,  38.45851, $
          148,        864,       1024,  38.10730, $
          149,        864,       1024,  37.75608, $
          150,        864,       1024,  37.40486, $
          151,        864,       1024,  37.05364, $
          152,        864,       1024,  36.70242, $
          153,        864,       1024,  36.35120, $
          154,        864,       1024,  35.99998, $
          155,        864,       1024,  35.64876, $
          156,        864,       1024,  35.29754, $
          157,        864,       1024,  34.94632, $
          158,        900,       1024,  34.59510, $
          159,        900,       1024,  34.24388, $
          160,        900,       1024,  33.89266]
  n256 = [n256, $
          161,        900,       1024,  33.54145, $
          162,        900,       1024,  33.19023, $
          163,        900,       1024,  32.83901, $
          164,        900,       1024,  32.48779, $
          165,        900,       1024,  32.13657, $
          166,        900,       1024,  31.78535, $
          167,        900,       1024,  31.43413, $
          168,        900,       1024,  31.08291, $
          169,        960,       1024,  30.73169, $
          170,        960,       1024,  30.38047, $
          171,        960,       1024,  30.02925, $
          172,        960,       1024,  29.67803, $
          173,        960,       1024,  29.32681, $
          174,        960,       1024,  28.97559, $
          175,        960,       1024,  28.62438, $
          176,        960,       1024,  28.27316, $
          177,        960,       1024,  27.92194, $
          178,        960,       1024,  27.57072, $
          179,        960,       1024,  27.21950, $
          180,        960,       1024,  26.86828, $
          181,        960,       1024,  26.51706, $
          182,        960,       1024,  26.16584, $
          183,        960,       1024,  25.81462, $
          184,        960,       1024,  25.46340, $
          185,        960,       1024,  25.11218, $
          186,        960,       1024,  24.76096, $
          187,        960,       1024,  24.40974, $
          188,        960,       1024,  24.05852, $
          189,        960,       1024,  23.70731, $
          190,        960,       1024,  23.35609, $
          191,        972,       1024,  23.00487, $
          192,        972,       1024,  22.65365, $
          193,        972,       1024,  22.30243, $
          194,        972,       1024,  21.95121, $
          195,        972,       1024,  21.59999, $
          196,       1000,       1024,  21.24877, $
          197,       1000,       1024,  20.89755, $
          198,       1000,       1024,  20.54633, $
          199,       1000,       1024,  20.19511, $
          200,       1000,       1024,  19.84389, $
          201,       1000,       1024,  19.49267, $
          202,       1000,       1024,  19.14145, $
          203,       1000,       1024,  18.79023, $
          204,       1000,       1024,  18.43902, $
          205,       1000,       1024,  18.08780, $
          206,       1000,       1024,  17.73658, $
          207,       1000,       1024,  17.38536, $
          208,       1000,       1024,  17.03414, $
          209,       1000,       1024,  16.68292, $
          210,       1000,       1024,  16.33170, $
          211,       1000,       1024,  15.98048, $
          212,       1024,       1024,  15.62926, $
          213,       1024,       1024,  15.27804, $
          214,       1024,       1024,  14.92682, $
          215,       1024,       1024,  14.57560, $
          216,       1024,       1024,  14.22438, $
          217,       1024,       1024,  13.87316, $
          218,       1024,       1024,  13.52194, $
          219,       1024,       1024,  13.17073, $
          220,       1024,       1024,  12.81951, $
          221,       1024,       1024,  12.46829, $
          222,       1024,       1024,  12.11707, $
          223,       1024,       1024,  11.76585, $
          224,       1024,       1024,  11.41463, $
          225,       1024,       1024,  11.06341, $
          226,       1024,       1024,  10.71219, $
          227,       1024,       1024,  10.36097, $
          228,       1024,       1024,  10.00975, $
          229,       1024,       1024,   9.65853, $
          230,       1024,       1024,   9.30731, $
          231,       1024,       1024,   8.95609, $
          232,       1024,       1024,   8.60487, $
          233,       1024,       1024,   8.25365, $
          234,       1024,       1024,   7.90244, $
          235,       1024,       1024,   7.55122, $
          236,       1024,       1024,   7.20000, $
          237,       1024,       1024,   6.84878, $
          238,       1024,       1024,   6.49756, $
          239,       1024,       1024,   6.14634, $
          240,       1024,       1024,   5.79512]
  n256 = [n256, $
          241,       1024,       1024,   5.44390, $
          242,       1024,       1024,   5.09268, $
          243,       1024,       1024,   4.74146, $
          244,       1024,       1024,   4.39024, $
          245,       1024,       1024,   4.03902, $
          246,       1024,       1024,   3.68780, $
          247,       1024,       1024,   3.33658, $
          248,       1024,       1024,   2.98536, $
          249,       1024,       1024,   2.63415, $
          250,       1024,       1024,   2.28293, $
          251,       1024,       1024,   1.93171, $
          252,       1024,       1024,   1.58049, $
          253,       1024,       1024,   1.22927, $
          254,       1024,       1024,   0.87805, $
          255,       1024,       1024,   0.52683, $
          256,       1024,       1024,   0.17561]
;
  n256 = reform(n256, 4, 256, /over)
  n256 = reform(n256[3, *], /over)
  n256 = [n256, -reverse(n256)]

  return, n256
end
